<!DOCTYPE TS><TS>
<context>
    <name>QAccel</name>
    <message>
        <source>Space</source>
        <translation>Пробел</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation></translation>
    </message>
    <message>
        <source>Backtab</source>
        <translation></translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation></translation>
    </message>
    <message>
        <source>Return</source>
        <translation></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation></translation>
    </message>
    <message>
        <source>Ins</source>
        <translation></translation>
    </message>
    <message>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation></translation>
    </message>
    <message>
        <source>Print</source>
        <translation></translation>
    </message>
    <message>
        <source>SysReq</source>
        <translation></translation>
    </message>
    <message>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <source>Left</source>
        <translation></translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Стрелка вверх</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Стрелка вправо</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Стрелка вниз</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <source>CapsLock</source>
        <translation></translation>
    </message>
    <message>
        <source>NumLock</source>
        <translation></translation>
    </message>
    <message>
        <source>ScrollLock</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation></translation>
    </message>
    <message>
        <source>Alt</source>
        <translation></translation>
    </message>
    <message>
        <source>Shift</source>
        <translation></translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>F%1</source>
        <translation></translation>
    </message>
    <message>
        <source>Menu</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation></translation>
    </message>
    <message>
        <source>Back</source>
        <translation></translation>
    </message>
    <message>
        <source>Forward</source>
        <translation></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation></translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation></translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation></translation>
    </message>
    <message>
        <source>Volume Mute</source>
        <translation></translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation></translation>
    </message>
    <message>
        <source>Bass Boost</source>
        <translation></translation>
    </message>
    <message>
        <source>Bass Up</source>
        <translation></translation>
    </message>
    <message>
        <source>Bass Down</source>
        <translation></translation>
    </message>
    <message>
        <source>Treble Up</source>
        <translation></translation>
    </message>
    <message>
        <source>Treble Down</source>
        <translation></translation>
    </message>
    <message>
        <source>Media Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <source>Media Stop</source>
        <translation>Остановить воспроизведение</translation>
    </message>
    <message>
        <source>Media Previous</source>
        <translation>Воспроизвести предыдущее</translation>
    </message>
    <message>
        <source>Media Next</source>
        <translation>Воспроизвести следующее</translation>
    </message>
    <message>
        <source>Media Record</source>
        <translation>Запись</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Standby</source>
        <translation></translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch Mail</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch Media</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (0)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (1)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (2)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (3)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (4)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (5)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (6)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (7)</source>
        <translation>Запустить (7)</translation>
    </message>
    <message>
        <source>Launch (8)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (9)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (A)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (B)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (C)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (D)</source>
        <translation>Запустить (D)</translation>
    </message>
    <message>
        <source>Launch (E)</source>
        <translation></translation>
    </message>
    <message>
        <source>Launch (F)</source>
        <translation></translation>
    </message>
    <message>
        <source>Meta</source>
        <translation></translation>
    </message>
    <message>
        <source>%1, %2 not defined</source>
        <translation>%1, %2 не определено</translation>
    </message>
    <message>
        <source>Ambiguous &quot;%1&quot; not handled</source>
        <translation>Неоднозначное &quot;%1&quot; не поддерживается</translation>
    </message>
    <message>
        <source>Print Screen</source>
        <translation></translation>
    </message>
    <message>
        <source>Page Up</source>
        <translation></translation>
    </message>
    <message>
        <source>Page Down</source>
        <translation></translation>
    </message>
    <message>
        <source>Caps Lock</source>
        <translation></translation>
    </message>
    <message>
        <source>Num Lock</source>
        <translation></translation>
    </message>
    <message>
        <source>Number Lock</source>
        <translation></translation>
    </message>
    <message>
        <source>Scroll Lock</source>
        <translation></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <source>Escape</source>
        <translation></translation>
    </message>
    <message>
        <source>System Request</source>
        <translation>Системный запрос</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>QT_LAYOUT_DIRECTION</source>
        <comment>Translate this string to the string &apos;LTR&apos; in left-to-right languages or to &apos;RTL&apos; in right-to-left languages (such as Hebrew and Arabic) to get proper widget layout.</comment>
        <translation>LTR</translation>
    </message>
    <message>
        <source>Executable &apos;%1&apos; requires Qt %2, found Qt %3.</source>
        <translation>Программный модуль &apos;%1&apos; требует Qt %2, найдена версия Qt %3.</translation>
    </message>
    <message>
        <source>Incompatible Qt Library Error</source>
        <translation>Ошибка совместимости библиотеки Qt</translation>
    </message>
</context>
<context>
    <name>QAquaStyle</name>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Отмена</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>&amp;Тон:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Насыщенность:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Яркость:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Красный:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Зелёный:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>С&amp;иний:</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation>&amp;Альфа-канал:</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>&amp;Основные цвета</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>&amp;Собственные цвета</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation>&amp;Выбрать собственные цвета &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Добавить к собственным цветам</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation>Выбрать цвет</translation>
    </message>
</context>
<context>
    <name>QDataTable</name>
    <message>
        <source>True</source>
        <translation>Правда</translation>
    </message>
    <message>
        <source>False</source>
        <translation>Ложь</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <source>What&apos;s This?</source>
        <translation>Что это такое?</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помошь</translation>
    </message>
</context>
<context>
    <name>QDialogButtons</name>
    <message>
        <source>Yes to All</source>
        <translation>Да для всех</translation>
    </message>
    <message>
        <source>OK to All</source>
        <translation>Ок для всех</translation>
    </message>
    <message>
        <source>No to All</source>
        <translation>Нет для всех</translation>
    </message>
    <message>
        <source>Cancel All</source>
        <translation>Отмена для всех</translation>
    </message>
    <message>
        <source> to All</source>
        <translation>для всех</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Повторить</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
</context>
<context>
    <name>QErrorMessage</name>
    <message>
        <source>&amp;Show this message again</source>
        <translation>&amp;Показывать это сообщение в дальнейшем</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Debug Message:</source>
        <translation>Отладочное сообщение:</translation>
    </message>
    <message>
        <source>Warning:</source>
        <translation>Предупреждение:</translation>
    </message>
    <message>
        <source>Fatal Error:</source>
        <translation>Критическая ошибка:</translation>
    </message>
</context>
<context>
    <name>QFile</name>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>Could not read from the file</source>
        <translation>Не удается прочитать из файла</translation>
    </message>
    <message>
        <source>Could not write to the file</source>
        <translation>Не удается записать в файл</translation>
    </message>
    <message>
        <source>Permission denied</source>
        <translation>Нет прав</translation>
    </message>
    <message>
        <source>Too many open files</source>
        <translation>Слишком много открытых файлов</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Именно такого файла или каталога нет</translation>
    </message>
    <message>
        <source>No space left on device</source>
        <translation>Нет места на диске</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Copy or Move a File</source>
        <translation>Копировать или переместить файл</translation>
    </message>
    <message>
        <source>Read: %1</source>
        <translation>Открытие: %1</translation>
    </message>
    <message>
        <source>Write: %1</source>
        <translation>Запись: %1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Все файлы (*)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Attributes</source>
        <translation>Атрибуты</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Look &amp;in:</source>
        <translation>&amp;Искать в:</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>&amp;Имя файла:</translation>
    </message>
    <message>
        <source>File &amp;type:</source>
        <translation>&amp;Тип файла:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>One directory up</source>
        <translation>Вверх на один уровень</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Создать новый каталог</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Подробный вид</translation>
    </message>
    <message>
        <source>Preview File Info</source>
        <translation>Предварительный просмотр информации о файле</translation>
    </message>
    <message>
        <source>Preview File Contents</source>
        <translation>Предварительный просмотр содержимого файла</translation>
    </message>
    <message>
        <source>Read-write</source>
        <translation>Чтение-запись</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Только чтение</translation>
    </message>
    <message>
        <source>Write-only</source>
        <translation>Только запись</translation>
    </message>
    <message>
        <source>Inaccessible</source>
        <translation>Нет доступа</translation>
    </message>
    <message>
        <source>Symlink to File</source>
        <translation>Ссылка на файл</translation>
    </message>
    <message>
        <source>Symlink to Directory</source>
        <translation>Ссылка на каталог</translation>
    </message>
    <message>
        <source>Symlink to Special</source>
        <translation>Ссылка на спецфайл</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Dir</source>
        <translation>Каталог</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Спецфайл</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Переименовать</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>R&amp;eload</source>
        <translation>О&amp;бновить</translation>
    </message>
    <message>
        <source>Sort by &amp;Name</source>
        <translation>По &amp;имени</translation>
    </message>
    <message>
        <source>Sort by &amp;Size</source>
        <translation>По &amp;размеру</translation>
    </message>
    <message>
        <source>Sort by &amp;Date</source>
        <translation>По &amp;дате</translation>
    </message>
    <message>
        <source>&amp;Unsorted</source>
        <translation>&amp;Не упорядочивать</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Упорядочить</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Показать &amp;скрытые файлы</translation>
    </message>
    <message>
        <source>the file</source>
        <translation>файл</translation>
    </message>
    <message>
        <source>the directory</source>
        <translation>каталог</translation>
    </message>
    <message>
        <source>the symlink</source>
        <translation>ссылка</translation>
    </message>
    <message>
        <source>Delete %1</source>
        <translation>Удалить %1</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Are you sure you wish to delete %1 &quot;%2&quot;?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Вы действительно хотите удалить %1 &quot;%2&quot;?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <source>New Folder 1</source>
        <translation>Новый каталог 1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Новый каталог</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <translation>Новый каталог %1</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Найти каталог</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Каталоги</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Сохранить</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>%1
File not found.
Check path and filename.</source>
        <translation>%1
Файл не найден.
Проверьте правильность пути и имени файла.</translation>
    </message>
    <message>
        <source>All Files (*.*)</source>
        <translation type="obsolete">Все файлы (*.*)</translation>
    </message>
    <message>
        <source>Open </source>
        <translation type="obsolete">Открыть</translation>
    </message>
    <message>
        <source>Select a Directory</source>
        <translation type="obsolete">Выбрать каталог</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Каталог:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>QFont</name>
    <message>
        <source>Latin</source>
        <translation>Латинский</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Греческий</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Кириллица</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>Армянский</translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation>Грузинский</translation>
    </message>
    <message>
        <source>Runic</source>
        <translation>Рунический</translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation>Огам</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Иврит</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Арабский</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>Сирийский</translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation></translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation>Деванагари</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>Бенгальский</translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation></translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation></translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>Ория</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Тамильский</translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation>Телугу</translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation>Каннада</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation>Малайялам</translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation></translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Тайский</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>Лаосский</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>Тибетский</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation></translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation>Кхмерский</translation>
    </message>
    <message>
        <source>Han</source>
        <translation></translation>
    </message>
    <message>
        <source>Hiragana</source>
        <translation></translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation></translation>
    </message>
    <message>
        <source>Hangul</source>
        <translation>Хангул</translation>
    </message>
    <message>
        <source>Bopomofo</source>
        <translation></translation>
    </message>
    <message>
        <source>Yi</source>
        <translation></translation>
    </message>
    <message>
        <source>Ethiopic</source>
        <translation>Эфиопский</translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation>Ирокезский</translation>
    </message>
    <message>
        <source>Canadian Aboriginal</source>
        <translation>Канадский аборигенный</translation>
    </message>
    <message>
        <source>Mongolian</source>
        <translation>Монгольский</translation>
    </message>
    <message>
        <source>Currency Symbols</source>
        <translation>Валютные символы</translation>
    </message>
    <message>
        <source>Letterlike Symbols</source>
        <translation>Буквенные символы</translation>
    </message>
    <message>
        <source>Number Forms</source>
        <translation>Числовые знаки</translation>
    </message>
    <message>
        <source>Mathematical Operators</source>
        <translation>Математические операторы</translation>
    </message>
    <message>
        <source>Technical Symbols</source>
        <translation>Технические символы</translation>
    </message>
    <message>
        <source>Geometric Symbols</source>
        <translation>Геометрические символы</translation>
    </message>
    <message>
        <source>Miscellaneous Symbols</source>
        <translation>Разнообразные символы</translation>
    </message>
    <message>
        <source>Enclosed and Square</source>
        <translation>Вложенные символы</translation>
    </message>
    <message>
        <source>Braille</source>
        <translation>Символы Брайля</translation>
    </message>
    <message>
        <source>Unicode</source>
        <translation>Юникод</translation>
    </message>
    <message>
        <source>SpacingModifiers</source>
        <translation></translation>
    </message>
    <message>
        <source>CombiningMarks</source>
        <translation></translation>
    </message>
    <message>
        <source>Tagalog</source>
        <translation></translation>
    </message>
    <message>
        <source>Hanunoo</source>
        <translation></translation>
    </message>
    <message>
        <source>Buhid</source>
        <translation></translation>
    </message>
    <message>
        <source>Tagbanwa</source>
        <translation></translation>
    </message>
    <message>
        <source>Katakana Half-Width Forms</source>
        <translation>Katakana c половинными формами</translation>
    </message>
    <message>
        <source>Han (Japanese)</source>
        <translation>Han (Японский)</translation>
    </message>
    <message>
        <source>Han (Simplified Chinese)</source>
        <translation>Han (упрощенный Китайский)</translation>
    </message>
    <message>
        <source>Han (Traditional Chinese)</source>
        <translation>Han (традиционный Китайский)</translation>
    </message>
    <message>
        <source>Han (Korean)</source>
        <translation>Han (Корейский)</translation>
    </message>
    <message>
        <source>Unknown Script</source>
        <translation>Неизвестный скрипт</translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Шрифт</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>&amp;Стиль шрифта</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Размер</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Эффекты</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation>&amp;Перечеркивать</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>П&amp;одчеркивать</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="obsolete">&amp;Цвет</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Пример</translation>
    </message>
    <message>
        <source>Scr&amp;ipt</source>
        <translation>&amp;Набор</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Выбрать шрифт</translation>
    </message>
</context>
<context>
    <name>QFtp</name>
    <message>
        <source>Host %1 found</source>
        <translation>Обнаружен узел %1</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Узел обнаружен</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Установлено соединение с узлом %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Соединение с узлом установлено</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Соединение с узлом %1 разорвано</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Соединение разорвано</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Узел %1 не обнаружен</translation>
    </message>
    <message>
        <source>Connection refused to host %1</source>
        <translation>Отказано в соединении с узлом %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>Connecting to host failed:
%1</source>
        <translation>Ошибка соединения с узлом:
%1</translation>
    </message>
    <message>
        <source>Login failed:
%1</source>
        <translation>Ошибка входа в систему:
%1</translation>
    </message>
    <message>
        <source>Listing directory failed:
%1</source>
        <translation>Ошибка просмотра каталога:
%1</translation>
    </message>
    <message>
        <source>Changing directory failed:
%1</source>
        <translation>Ошибка смены каталога:
%1</translation>
    </message>
    <message>
        <source>Downloading file failed:
%1</source>
        <translation>Ошибка загрузки файла:
%1</translation>
    </message>
    <message>
        <source>Uploading file failed:
%1</source>
        <translation>Ошибка отправки файла:
%1</translation>
    </message>
    <message>
        <source>Removing file failed:
%1</source>
        <translation>Ошибка удаления файла:
%1</translation>
    </message>
    <message>
        <source>Creating directory failed:
%1</source>
        <translation>Ошибка создания каталога:
%1</translation>
    </message>
    <message>
        <source>Removing directory failed:
%1</source>
        <translation>Ошибка удаления каталога:
%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Нет соединения</translation>
    </message>
    <message>
        <source>Connection refused for data connection</source>
        <translation>Отказано в соединении передачи данных</translation>
    </message>
</context>
<context>
    <name>QHeader</name>
    <message>
        <source>%1</source>
        <translation type="obsolete">%1</translation>
    </message>
</context>
<context>
    <name>QHttp</name>
    <message>
        <source>Connection refused</source>
        <translation>Отказано в соединении</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Узел %1 не обнаружен</translation>
    </message>
    <message>
        <source>Wrong content length</source>
        <translation>Неверная длина данных</translation>
    </message>
    <message>
        <source>HTTP request failed</source>
        <translation>Ошибка HTTP-запроса</translation>
    </message>
    <message>
        <source>Host %1 found</source>
        <translation>Обнаружен узел %1</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Узел обнаружен</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Установлено соединение с узлом %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Соединение с узлом установлено</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Соединение с узлом %1 разорвано</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Соединение разорвано</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>Request aborted</source>
        <translation>Запрос отменен</translation>
    </message>
    <message>
        <source>No server set to connect to</source>
        <translation>Не выбран сервер для подключения</translation>
    </message>
    <message>
        <source>Server closed connection unexpectedly</source>
        <translation>Неожиданный разрыв соединения сервером</translation>
    </message>
    <message>
        <source>Invalid HTTP response header</source>
        <translation>Получен некорректный HTTP-заголовок</translation>
    </message>
    <message>
        <source>Invalid HTTP chunked body</source>
        <translation>Некорректный HTTP-ответ</translation>
    </message>
</context>
<context>
    <name>QInputDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Вырезать</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>В&amp;ставить</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить все</translation>
    </message>
</context>
<context>
    <name>QLocalFs</name>
    <message>
        <source>Could not rename
%1
to
%2</source>
        <translation>Невозможно переименовать
%1
в
%2</translation>
    </message>
    <message>
        <source>Could not open
%1</source>
        <translation>Невозможно открыть
%1</translation>
    </message>
    <message>
        <source>Could not write
%1</source>
        <translation>Невозможно записать
%1</translation>
    </message>
    <message>
        <source>Could not read directory
%1</source>
        <translation>Невозможно просмотреть каталог
%1</translation>
    </message>
    <message>
        <source>Could not create directory
%1</source>
        <translation>Невозможно создать каталог
%1</translation>
    </message>
    <message>
        <source>Could not remove file or directory
%1</source>
        <translation>Невозможно удалить файл или каталог
%1</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Line up</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <source>Customize...</source>
        <translation>Настроить...</translation>
    </message>
</context>
<context>
    <name>QMenuBar</name>
    <message>
        <source>About</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>Config</source>
        <translation type="obsolete">Конфигурация</translation>
    </message>
    <message>
        <source>Preference</source>
        <translation type="obsolete">Параметры</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="obsolete">Параметры</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation type="obsolete">Настройки</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation type="obsolete">Настройки</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="obsolete">Выход</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Выход</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation>&amp;Прервать</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>П&amp;овторить</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Игнорировать</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation>&lt;h3&gt;О Qt&lt;/h3&gt;&lt;p&gt;Эта программа использует Qt версии %1.&lt;/p&gt;&lt;p&gt;Qt - это C++ GUI инструментарий для разработки многоплатформенных приложений.&lt;/p&gt;&lt;p&gt;Qt обеспечивает переносимость на уровне исходного кода между MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux и всеми основными версиями Unix.&lt;br&gt;Qt также доступен для встраиваемых систем.&lt;/p&gt;&lt;p&gt;Qt является продуктом Trolltech. Посетите &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; для получения более подробной информации.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Yes to &amp;All</source>
        <translation>Да для &amp;всех</translation>
    </message>
    <message>
        <source>N&amp;o to All</source>
        <translation>&amp;Нет для всех</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>О Qt</translation>
    </message>
</context>
<context>
    <name>QNetworkProtocol</name>
    <message>
        <source>Operation stopped by the user</source>
        <translation>Операция прервана пользователем</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>On The Spot</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QPrintDialog</name>
    <message>
        <source>locally connected</source>
        <translation>локальный</translation>
    </message>
    <message>
        <source>Aliases: %1</source>
        <translation>Алиасы: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>неизвестно</translation>
    </message>
    <message>
        <source>Unknown Location</source>
        <translation>неизвестно</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Printer settings</source>
        <translation>Настройки печати</translation>
    </message>
    <message>
        <source>Print in color if available</source>
        <translation>Цветная печать</translation>
    </message>
    <message>
        <source>Print in grayscale</source>
        <translation>В оттенках серого</translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation>Направление печати</translation>
    </message>
    <message>
        <source>Print to printer:</source>
        <translation>Печать на принтер:</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Принтер</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Узел</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <source>Print to file:</source>
        <translation>Печать в файл:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Печатать все</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Печатать диапазон</translation>
    </message>
    <message>
        <source>From page:</source>
        <translation>Со страницы:</translation>
    </message>
    <message>
        <source>To page:</source>
        <translation>До страницы:</translation>
    </message>
    <message>
        <source>Print first page first</source>
        <translation>Начать с первой страницы</translation>
    </message>
    <message>
        <source>Print last page first</source>
        <translation>Начать с последней страницы</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Число копий:</translation>
    </message>
    <message>
        <source>Paper format</source>
        <translation>Формат бумаги</translation>
    </message>
    <message>
        <source>Portrait</source>
        <translation>Книжный</translation>
    </message>
    <message>
        <source>Landscape</source>
        <translation>Альбомный</translation>
    </message>
    <message>
        <source>A0 (841 x 1189 mm)</source>
        <translation>A0 (841 x 1189 мм)</translation>
    </message>
    <message>
        <source>A1 (594 x 841 mm)</source>
        <translation>A1 (594 x 841 мм)</translation>
    </message>
    <message>
        <source>A2 (420 x 594 mm)</source>
        <translation>A2 (420 x 594 мм)</translation>
    </message>
    <message>
        <source>A3 (297 x 420 mm)</source>
        <translation>A3 (297 x 420 мм)</translation>
    </message>
    <message>
        <source>A4 (210x297 mm, 8.26x11.7 inches)</source>
        <translation>A4 (210x297 мм, 8.26x11.7 дюйм)</translation>
    </message>
    <message>
        <source>A5 (148 x 210 mm)</source>
        <translation>A5 (148 x 210 мм)</translation>
    </message>
    <message>
        <source>A6 (105 x 148 mm)</source>
        <translation>A6 (105 x 148 мм)</translation>
    </message>
    <message>
        <source>A7 (74 x 105 mm)</source>
        <translation>A7 (74 x 105 мм)</translation>
    </message>
    <message>
        <source>A8 (52 x 74 mm)</source>
        <translation>A8 (52 x 74 мм)</translation>
    </message>
    <message>
        <source>A9 (37 x 52 mm)</source>
        <translation>A9 (37 x 52 мм)</translation>
    </message>
    <message>
        <source>B0 (1000 x 1414 mm)</source>
        <translation>B0 (1000 x 1414 мм)</translation>
    </message>
    <message>
        <source>B1 (707 x 1000 mm)</source>
        <translation>B1 (707 x 1000 мм)</translation>
    </message>
    <message>
        <source>B2 (500 x 707 mm)</source>
        <translation>B2 (500 x 707 мм)</translation>
    </message>
    <message>
        <source>B3 (353 x 500 mm)</source>
        <translation>B3 (353 x 500 мм)</translation>
    </message>
    <message>
        <source>B4 (250 x 353 mm)</source>
        <translation>B4 (250 x 353 мм)</translation>
    </message>
    <message>
        <source>B5 (176 x 250 mm, 6.93x9.84 inches)</source>
        <translation>B5 (176x250 мм, 6.93x9.84 дюйм)</translation>
    </message>
    <message>
        <source>B6 (125 x 176 mm)</source>
        <translation>B6 (125 x 176 мм)</translation>
    </message>
    <message>
        <source>B7 (88 x 125 mm)</source>
        <translation>B7 (88 x 125 мм)</translation>
    </message>
    <message>
        <source>B8 (62 x 88 mm)</source>
        <translation>B8 (62 x 88 мм)</translation>
    </message>
    <message>
        <source>B9 (44 x 62 mm)</source>
        <translation>B9 (44 x 62 мм)</translation>
    </message>
    <message>
        <source>B10 (31 x 44 mm)</source>
        <translation>B10 (31 x 44 мм)</translation>
    </message>
    <message>
        <source>C5E (163 x 229 mm)</source>
        <translation>C5E (163 x 229 мм)</translation>
    </message>
    <message>
        <source>DLE (110 x 220 mm)</source>
        <translation>DLE (110 x 220 мм)</translation>
    </message>
    <message>
        <source>Executive (7.5x10 inches, 191x254 mm)</source>
        <translation>Executive (7.5x10 дюйм, 191x254 мм)</translation>
    </message>
    <message>
        <source>Folio (210 x 330 mm)</source>
        <translation>Folio (210 x 330 мм)</translation>
    </message>
    <message>
        <source>Ledger (432 x 279 mm)</source>
        <translation>Ledger (432 x 279 мм)</translation>
    </message>
    <message>
        <source>Legal (8.5x14 inches, 216x356 mm)</source>
        <translation>Legal (8.5x14 дюйм, 216x356 мм)</translation>
    </message>
    <message>
        <source>Letter (8.5x11 inches, 216x279 mm)</source>
        <translation>Letter (8.5x11 дюйм, 216x279 мм)</translation>
    </message>
    <message>
        <source>Tabloid (279 x 432 mm)</source>
        <translation>Tabloid (279 x 432 мм)</translation>
    </message>
    <message>
        <source>US Common #10 Envelope (105 x 241 mm)</source>
        <translation>Конверт US #10 (105x241 мм)</translation>
    </message>
    <message>
        <source>Setup Printer</source>
        <translation>Настройки принтера</translation>
    </message>
    <message>
        <source>PostScript Files (*.ps);;All Files (*)</source>
        <translation>Файлы PostScript (*.ps);;Все файлы (*)</translation>
    </message>
    <message>
        <source>Print selection</source>
        <translation>Печатать выделенное</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QRegExp</name>
    <message>
        <source>no error occurred</source>
        <translation>ошибок не произошло</translation>
    </message>
    <message>
        <source>disabled feature used</source>
        <translation>использовались отключенные возможности</translation>
    </message>
    <message>
        <source>bad char class syntax</source>
        <translation>ошибочный синтаксис класса  символа</translation>
    </message>
    <message>
        <source>bad lookahead syntax</source>
        <translation>ошибочный синтаксис упреждающего чтения</translation>
    </message>
    <message>
        <source>bad repetition syntax</source>
        <translation>ошибочный синтаксис многократного чтения</translation>
    </message>
    <message>
        <source>invalid octal value</source>
        <translation>некорректное восьмеричное значение</translation>
    </message>
    <message>
        <source>missing left delim</source>
        <translation>отсутствует левый разделитель</translation>
    </message>
    <message>
        <source>unexpected end</source>
        <translation>неожиданный конец</translation>
    </message>
    <message>
        <source>met internal limit</source>
        <translation>достигнуто внутреннее ограничение</translation>
    </message>
</context>
<context>
    <name>QSql</name>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Delete this record?</source>
        <translation>Удалить эту запись?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Save edits?</source>
        <translation>Сохранить изменения?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <source>Cancel your edits?</source>
        <translation>Не сохранять изменения?</translation>
    </message>
</context>
<context>
    <name>QTabDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QTextEdit</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Вы&amp;резать</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>В&amp;ставить</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить все</translation>
    </message>
</context>
<context>
    <name>QTitleBar</name>
    <message>
        <source>System Menu</source>
        <translation>Системное меню</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>Свернуть в заголовок</translation>
    </message>
    <message>
        <source>Unshade</source>
        <translation>Восстановить из заголовка</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Развернуть</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>QToolBar</name>
    <message>
        <source>More...</source>
        <translation>Больше...</translation>
    </message>
</context>
<context>
    <name>QUrlOperator</name>
    <message>
        <source>The protocol `%1&apos; is not supported</source>
        <translation>Протокол `%1&apos; не поддерживается</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support listing directories</source>
        <translation>Протокол `%1&apos; не поддерживает просмотр каталогов</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support creating new directories</source>
        <translation>Протокол `%1&apos; не поддерживает создание новых каталогов</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support removing files or directories</source>
        <translation>Протокол `%1&apos; не поддерживает удаление файлов или каталогов</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support renaming files or directories</source>
        <translation>Протокол `%1&apos; не поддерживает переименование файлов или каталогов</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support getting files</source>
        <translation>Протокол `%1&apos; не поддерживает доставку файлов</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support putting files</source>
        <translation>Протокол `%1&apos; не поддерживает отправку файлов</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support copying or moving files or directories</source>
        <translation>Протокол `%1&apos; не поддерживает копирование или перемещение файлов и каталогов</translation>
    </message>
    <message>
        <source>(unknown)</source>
        <translation>(неизвестно)</translation>
    </message>
</context>
<context>
    <name>QWSDecoration</name>
    <message>
        <source>&amp;Restore</source>
        <translation type="obsolete">&amp;Восстановить</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation type="obsolete">&amp;Переместить</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation type="obsolete">&amp;Размер</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation type="obsolete">&amp;Свернуть</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation type="obsolete">Р&amp;азвернуть</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Закрыть</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation type="obsolete">Windows</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation type="obsolete">KDE</translation>
    </message>
    <message>
        <source>KDE2</source>
        <translation type="obsolete">KDE2</translation>
    </message>
    <message>
        <source>BeOS</source>
        <translation type="obsolete">BeOS</translation>
    </message>
    <message>
        <source>Hydro</source>
        <translation type="obsolete">Hydro</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">По умолчанию</translation>
    </message>
</context>
<context>
    <name>QWhatsThisButton</name>
    <message>
        <source>What&apos;s this?</source>
        <translation>Что это?</translation>
    </message>
</context>
<context>
    <name>QWizard</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <source>&lt; &amp;Back</source>
        <translation>&lt; &amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Next &gt;</source>
        <translation>&amp;Вперед &gt;</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Готово</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
</context>
<context>
    <name>QWorkspace</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Переместить</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Размер</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Свернуть</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Р&amp;азвернуть</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Stay on &amp;Top</source>
        <translation>Расположить &amp;поверх всех окон</translation>
    </message>
    <message>
        <source>Sh&amp;ade</source>
        <translation>Свернуть в за&amp;головок</translation>
    </message>
    <message>
        <source>%1 - [%2]</source>
        <translation>%1 - [%2]</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <source>Restore Down</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>&amp;Unshade</source>
        <translation>Восстановить из за&amp;головка</translation>
    </message>
</context>
<context>
    <name>QXml</name>
    <message>
        <source>no error occurred</source>
        <translation>ошибки отсутствуют</translation>
    </message>
    <message>
        <source>error triggered by consumer</source>
        <translation>ошибка инициирована пользователем</translation>
    </message>
    <message>
        <source>unexpected end of file</source>
        <translation>неожиданный конец файла</translation>
    </message>
    <message>
        <source>more than one document type definition</source>
        <translation>определен более, чем один тип документов</translation>
    </message>
    <message>
        <source>error occurred while parsing element</source>
        <translation>в процессе синтаксического анализа элемента произошла ошибка</translation>
    </message>
    <message>
        <source>tag mismatch</source>
        <translation>несоответствие тегов </translation>
    </message>
    <message>
        <source>error occurred while parsing content</source>
        <translation>в процессе синтаксического анализа произошла ошибка</translation>
    </message>
    <message>
        <source>unexpected character</source>
        <translation>неожиданный символ</translation>
    </message>
    <message>
        <source>invalid name for processing instruction</source>
        <translation>некорректное имя директивы</translation>
    </message>
    <message>
        <source>version expected while reading the XML declaration</source>
        <translation>при чтении XML-тега ожидался параметр version</translation>
    </message>
    <message>
        <source>wrong value for standalone declaration</source>
        <translation>некорректное значение параметра standalone</translation>
    </message>
    <message>
        <source>encoding declaration or standalone declaration expected while reading the XML declaration</source>
        <translation>при чтении XML-тега ожидался параметр encoding или параметр standalone</translation>
    </message>
    <message>
        <source>standalone declaration expected while reading the XML declaration</source>
        <translation>при чтении XML-тега ожидался параметр standalone</translation>
    </message>
    <message>
        <source>error occurred while parsing document type definition</source>
        <translation>в процессе синтаксического анализа типа документа произошла ошибка</translation>
    </message>
    <message>
        <source>letter is expected</source>
        <translation>ожидается символ</translation>
    </message>
    <message>
        <source>error occurred while parsing comment</source>
        <translation>в процессе синтаксического анализа комментария произошла ошибка</translation>
    </message>
    <message>
        <source>error occurred while parsing reference</source>
        <translation>в процессе синтаксического анализа ссылки произошла ошибка</translation>
    </message>
    <message>
        <source>internal general entity reference not allowed in DTD</source>
        <translation>ссылка на основные внутренние определения не разрешена в DTD</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in attribute value</source>
        <translation>ссылка на основные внутренние определения, обработанная извне, не разрешена в значении атрибута</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in DTD</source>
        <translation>ссылка на основные внутренние определения, обработанная извне, не разрешена в DTD</translation>
    </message>
    <message>
        <source>unparsed entity reference in wrong context</source>
        <translation>неанализированная ссылка на определение в неправильном контексте</translation>
    </message>
    <message>
        <source>recursive entities</source>
        <translation>рекурсивные определения</translation>
    </message>
    <message>
        <source>error in the text declaration of an external entity</source>
        <translation>ошибка в тексте описания внешнего определения</translation>
    </message>
</context>
<context>
    <name>QtMultiLineEdit</name>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Paste special...</source>
        <translation>Специальная вставка...</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить все</translation>
    </message>
</context>
</TS>
